@@ -272,13 +272,12 @@ private:
 	bool InfoFromSystem();
 
 	//! Load binary TOC (if available)
-	bool BinaryTOC(wxTreeCtrl *toBuild, const wxCSConv& cv);
+	bool BinaryTOC(wxTreeCtrl *toBuild);
 
 	//! Try to recursively load the binary topics tree
 	void RecurseLoadBTOC(UCharPtr& topidx, UCharPtr& topics,
 			     UCharPtr& strings, UCharPtr& urltbl,
 			     UCharPtr& urlstr, uint32_t offset, 
-			     const wxCSConv& cv,
 			     wxTreeCtrl *toBuild, int level);
 
 	//! Retrieve the data (name/URL) for a single entry (TOC or index)
