@@ -207,6 +207,9 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 
 CHMFrame::~CHMFrame()
 {
+	if(_tcl) // Supposedly, workaround for wxWin
+		_tcl->Unselect();
+
 	delete _ep;
 	delete _fixedFonts;
 	delete _normalFonts;
@@ -515,6 +518,9 @@ void CHMFrame::OnSelectionChanged(wxTreeEvent& event)
 	if(id == _tcl->GetRootItem() || !chmf)
 		return;
 
+	if(!id.IsOk())
+		return;
+
 	URLTreeItem *data = reinterpret_cast<URLTreeItem *>(
 		_tcl->GetItemData(id));
 
@@ -563,9 +569,8 @@ bool CHMFrame::LoadCHM(const wxString& archive)
 	   !archive.Contains(wxT("#xchm:"))) {
 
 		wxFileSystem wfs;
-		wxFSFile *f = wfs.OpenFile(wxString(wxT("file:")) + archive +
-			      wxT("#xchm:/"));
-		delete f;
+		std::auto_ptr<wxFSFile> p(wfs.OpenFile(wxString(wxT("file:")) + archive +
+			      wxT("#xchm:/")));
 	
 	        CHMFile *chmf = CHMInputStream::GetCache();
 
@@ -582,6 +587,7 @@ bool CHMFrame::LoadCHM(const wxString& archive)
 
 	if(!rtn) { // Error, could not load CHM file
 		if(_tcl->GetCount())
+			_tcl->Unselect();
 			_tcl->DeleteChildren(_tcl->GetRootItem());
 		if(_sw->IsSplit()) {
 			_sw->Unsplit(_nb);
@@ -620,7 +626,6 @@ bool CHMFrame::LoadContextID( const int contextID )
 					      chmf->GetPageByCID(contextID));
 }
 
-
 void CHMFrame::UpdateCHMInfo()
 {
 #if !wxUSE_UNICODE
@@ -649,26 +654,9 @@ void CHMFrame::UpdateCHMInfo()
 
 	wxString title = chmf->Title();
 
-	if(_tcl->GetCount())
+	if(_tcl->GetCount()) {
+		_tcl->Unselect();
 		_tcl->DeleteChildren(_tcl->GetRootItem());
-
-	if(_loadTopics)
-		chmf->GetTopicsTree(_tcl);
-	
-	if(_loadIndex)
-		chmf->GetIndex(_cip->GetResultsList());
-	
-	if(!title.IsEmpty()) {
-		wxString titleBarText = 
-			wxString(wxT("xCHM v. " wxT(VERSION) wxT(": "))) 
-                        + title;
-
-		SetTitle(titleBarText);
-		_nbhtml->GetCurrentPage()->SetRelatedFrame(this, titleBarText);
-	} else {
-		SetTitle(wxT("xCHM v. ") wxT(VERSION));
-		_nbhtml->GetCurrentPage()
-			->SetRelatedFrame(this, wxT("xCHM v. ") wxT(VERSION));
 	}
 
 #if !wxUSE_UNICODE
@@ -726,6 +714,24 @@ void CHMFrame::UpdateCHMInfo()
 		noSpecialFont = true;
 	}
 #endif
+	if(_loadTopics)
+		chmf->GetTopicsTree(_tcl);
+	
+	if(_loadIndex)
+		chmf->GetIndex(_cip->GetResultsList());
+	
+	if(!title.IsEmpty()) {
+		wxString titleBarText = 
+			wxString(wxT("xCHM v. " wxT(VERSION) wxT(": "))) 
+                        + title;
+
+		SetTitle(titleBarText);
+		_nbhtml->GetCurrentPage()->SetRelatedFrame(this, titleBarText);
+	} else {
+		SetTitle(wxT("xCHM v. ") wxT(VERSION));
+		_nbhtml->GetCurrentPage()
+			->SetRelatedFrame(this, wxT("xCHM v. ") wxT(VERSION));
+	}
 	
 	// if we have contents..
 	if(_tcl->GetCount() >= 1) {		
