@@ -318,7 +318,7 @@ void CHMHtmlWindow::OnSaveLinkAs(wxCommandEvent& WXUNUSED(event))
 					     suggestedName,
 					     wxT(""),
 					     wxT("*.*"),
-					     wxSAVE | wxOVERWRITE_PROMPT,
+					     wxFD_SAVE | wxFD_OVERWRITE_PROMPT,
 					     this);
 	if (!filename.empty()) {
 		wxInputStream *s = f->GetStream();
@@ -386,11 +386,40 @@ void CHMHtmlWindow::OnOpenInNewTab(wxCommandEvent& WXUNUSED(event))
 
 void CHMHtmlWindow::OnChar(wxKeyEvent& event)
 {
-	if(event.GetKeyCode() == WXK_SPACE) {
-		event.m_keyCode = WXK_PAGEDOWN;
+	int x = 0, y = 0;
+	int xUnit = 0, yUnit = 0;
 
-	} else if(event.GetKeyCode() == WXK_BACK) {
+	switch(event.GetKeyCode()) {
+	case WXK_SPACE:
+		event.m_keyCode = WXK_PAGEDOWN;
+		break;
+	case WXK_BACK:
 		event.m_keyCode = WXK_PAGEUP;
+		break;
+	case 'g':
+	case WXK_HOME:
+		Scroll(0, 0);
+		break;
+	case WXK_END:
+	case 'G':
+		GetVirtualSize(&x, &y);
+		GetScrollPixelsPerUnit(&xUnit, &yUnit);
+		Scroll(0, y / yUnit);
+		break;
+	case 'j':
+		event.m_keyCode = WXK_DOWN;
+		break;
+	case 'k':
+		event.m_keyCode = WXK_UP;
+		break;
+	case 'h':
+		event.m_keyCode = WXK_LEFT;
+		break;
+	case 'l':
+		event.m_keyCode = WXK_RIGHT;
+		break;
+	default:
+		break;
 	}
 
 	event.Skip();
