@@ -110,13 +110,13 @@ size_t CHMInputStream::GetSize() const
 
 bool CHMInputStream::Eof() const
 {
-	return _currPos >= (off_t)_ui.length;
+	return (uint64_t)_currPos >= _ui.length;
 }
 
 
 size_t CHMInputStream::OnSysRead(void *buffer, size_t bufsize)
 {	
-	if(_currPos >= (off_t)_ui.length) {
+	if((uint64_t)_currPos >= _ui.length) {
 		m_lasterror = wxSTREAM_EOF;
 		return 0;
 	}
@@ -124,7 +124,7 @@ size_t CHMInputStream::OnSysRead(void *buffer, size_t bufsize)
 	if(!_archiveCache)
 		return 0;
 
-	if(_currPos + bufsize > (off_t)_ui.length)
+	if((uint64_t)(_currPos + bufsize) > _ui.length)
         bufsize = _ui.length - _currPos;
         
 	bufsize = 
