@@ -52,8 +52,7 @@ CHMSearchPanel::CHMSearchPanel(wxWindow *parent, wxTreeCtrl *topics,
 #if wxUSE_TOOLTIPS
 	_partial->SetToolTip(_("Allow partial matches."));
 	_titles->SetToolTip(_("Only search in the contents' titles."));
-	_search->SetToolTip(_("Search contents for occurences of"
-			      " the specified text."));
+	_search->SetToolTip(_("Search contents for occurences of the specified text."));
 #endif
 	_results = new CHMListCtrl(this, nbhtml, ID_Results);
 
@@ -163,13 +162,9 @@ void CHMSearchPanel::PopulateList(wxTreeItemId root, wxString& text,
 		_tcl->GetItemData(root));
 
 	if(data && (!data->_url.IsEmpty())) {
-
-		wxString url = wxString(wxT("file:")) + 
-			chmf->ArchiveName() + wxT("#xchm:/") + data->_url;
 		wxString title = _tcl->GetItemText(root);
-
 		if(TitleSearch(title, text, false, wholeWords))
-			_results->AddPairItem(title, url);
+			_results->AddPairItem(title, data->_url);
 	}	
 
 	wxTreeItemIdValue cookie;
